@@ -37,7 +37,7 @@ __license__ = "Apache-2.0"
 # do not change this line manually
 # this is managed by git tag and updated on every release
 # NOTE: this represents the NEXT release version
-__version__ = '0.9.17'
+__version__ = '0.9.21'
 
 # do not change this line manually
 # this is managed by proto/build-proto.sh and updated on every execution
@@ -54,11 +54,6 @@ __jina_env__ = ('JINA_ARRAY_QUANT',
                 'JINA_CONTRIB_MODULE',
                 'JINA_CONTRIB_MODULE_IS_LOADING',
                 'JINA_CONTROL_PORT',
-                'JINA_DB_COLLECTION',
-                'JINA_DB_HOSTNAME',
-                'JINA_DB_NAME',
-                'JINA_DB_PASSWORD',
-                'JINA_DB_USERNAME',
                 'JINA_DEFAULT_HOST',
                 'JINA_DISABLE_UVLOOP',
                 'JINA_EXECUTOR_WORKDIR',
@@ -66,7 +61,9 @@ __jina_env__ = ('JINA_ARRAY_QUANT',
                 'JINA_IPC_SOCK_TMP',
                 'JINA_LOG_CONFIG',
                 'JINA_LOG_ID',
+                'JINA_LOG_LEVEL',
                 'JINA_LOG_NO_COLOR',
+                'JINA_LOG_WORKSPACE',
                 'JINA_POD_NAME',
                 'JINA_RAISE_ERROR_EARLY',
                 'JINA_RANDOM_PORTS',
@@ -74,7 +71,8 @@ __jina_env__ = ('JINA_ARRAY_QUANT',
                 'JINA_RANDOM_PORT_MIN',
                 'JINA_SOCKET_HWM',
                 'JINA_VCS_VERSION',
-                'JINA_WARN_UNNAMED')
+                'JINA_WARN_UNNAMED',
+                'JINA_WORKSPACE')
 
 __default_host__ = _os.environ.get('JINA_DEFAULT_HOST', '0.0.0.0')
 __ready_msg__ = 'ready and listening'
@@ -162,6 +160,7 @@ from jina.clients import Client
 from jina.clients.asyncio import AsyncClient
 
 # Executor
+from jina.executors import BaseExecutor as Executor
 from jina.executors.classifiers import BaseClassifier as Classifier
 from jina.executors.crafters import BaseCrafter as Crafter
 from jina.executors.encoders import BaseEncoder as Encoder
