@@ -14,7 +14,7 @@ from typing import (
 
 from google.protobuf.struct_pb2 import Struct
 
-from ..enums import SkipOnErrorType
+from ..enums import OnErrorStrategy
 from ..executors import BaseExecutor
 from ..executors.compound import CompoundExecutor
 from ..executors.decorators import wrap_func
@@ -23,12 +23,12 @@ from ..jaml import JAMLCompatible
 
 if False:
     # fix type-hint complain for sphinx and flake
-    from ..peapods.peas import BasePea
+    from ..peapods.runtimes.zmq.zed import ZEDRuntime
     from ..executors import AnyExecutor
     from ..logging.logger import JinaLogger
     from ..types.message import Message
-    from ..types.request import Request
     from ..types.document import Document
+    from ..types.request import Request
     from ..types.sets import QueryLangSet, DocumentSet
 
 
@@ -137,12 +137,12 @@ class DriverType(type(JAMLCompatible), type):
 
 
 class BaseDriver(JAMLCompatible, metaclass=DriverType):
-    """A :class:`BaseDriver` is a logic unit above the :class:`jina.peapods.pea.BasePea`.
+    """A :class:`BaseDriver` is a logic unit above the :class:`jina.peapods.runtimes.zmq.zed.ZEDRuntime`.
     It reads the protobuf message, extracts/modifies the required information and then return
-    the message back to :class:`jina.peapods.pea.BasePea`.
+    the message back to :class:`jina.peapods.runtimes.zmq.zed.ZEDRuntime`.
 
-    A :class:`BaseDriver` needs to be :attr:`attached` to a :class:`jina.peapods.pea.BasePea` before using. This is done by
-    :func:`attach`. Note that a deserialized :class:`BaseDriver` from file is always unattached.
+    A :class:`BaseDriver` needs to be :attr:`attached` to a :class:`jina.peapods.runtimes.zmq.zed.ZEDRuntime` before
+    using. This is done by :func:`attach`. Note that a deserialized :class:`BaseDriver` from file is always unattached.
 
     """
 
@@ -154,43 +154,44 @@ class BaseDriver(JAMLCompatible, metaclass=DriverType):
         :param priority: the priority of its default arg values (hardcoded in Python). If the
              received ``QueryLang`` has a higher priority, it will override the hardcoded value
         """
-        self.attached = False  #: represent if this driver is attached to a :class:`jina.peapods.pea.BasePea` (& :class:`jina.executors.BaseExecutor`)
-        self.pea = None  # type: Optional['BasePea']
+        self.attached = False  # : represent if this driver is attached to a
+        # :class:`jina.peapods.runtimes.zmq.zed.ZEDRuntime` (& :class:`jina.executors.BaseExecutor`)
+        self.runtime = None  # type: Optional['ZEDRuntime']
         self._priority = priority
 
-    def attach(self, pea: 'BasePea', *args, **kwargs) -> None:
-        """Attach this driver to a :class:`jina.peapods.pea.BasePea`
+    def attach(self, runtime: 'ZEDRuntime', *args, **kwargs) -> None:
+        """Attach this driver to a :class:`jina.peapods.runtimes.zmq.zed.ZEDRuntime`
 
-        :param pea: the pea to be attached.
+        :param runtime: the pea to be attached.
         """
-        self.pea = pea
+        self.runtime = runtime
         self.attached = True
 
     @property
     def req(self) -> 'Request':
-        """Get the current (typed) request, shortcut to ``self.pea.request``"""
-        return self.pea.request
+        """Get the current (typed) request, shortcut to ``self.runtime.request``"""
+        return self.runtime.request
 
     @property
     def partial_reqs(self) -> Sequence['Request']:
         """The collected partial requests under the current ``request_id`` """
         if self.expect_parts > 1:
-            return self.pea.partial_requests
+            return self.runtime.partial_requests
         else:
             raise ValueError(
                 f'trying to access all partial requests, '
-                f'but {self.pea} has only one message'
+                f'but {self.runtime} has only one message'
             )
 
     @property
     def expect_parts(self) -> int:
         """The expected number of partial messages """
-        return self.pea.expect_parts
+        return self.runtime.expect_parts
 
     @property
     def msg(self) -> 'Message':
-        """Get the current request, shortcut to ``self.pea.message``"""
-        return self.pea.message
+        """Get the current request, shortcut to ``self.runtime.message``"""
+        return self.runtime.message
 
     @property
     def queryset(self) -> 'QueryLangSet':
@@ -199,10 +200,17 @@ class BaseDriver(JAMLCompatible, metaclass=DriverType):
         else:
             return []
 
+    @property
+    def docs(self):
+        if self.expect_parts > 1:
+            return (d for r in reversed(self.partial_reqs) for d in r.docs)
+        else:
+            return self.req.docs
+
     @property
     def logger(self) -> 'JinaLogger':
-        """Shortcut to ``self.pea.logger``"""
-        return self.pea.logger
+        """Shortcut to ``self.runtime.logger``"""
+        return self.runtime.logger
 
     def __call__(self, *args, **kwargs) -> None:
         raise NotImplementedError
@@ -220,12 +228,13 @@ class BaseDriver(JAMLCompatible, metaclass=DriverType):
         return self.__class__ == other.__class__
 
     def __getstate__(self) -> Dict[str, Any]:
-        """Do not save the BasePea, as it would be cross-referencing. In other words, a deserialized :class:`BaseDriver` from
-        file is always unattached."""
-        d = dict(self.__dict__)
-        if 'pea' in d:
-            del d['pea']
-        d['attached'] = False
+        """
+        Unlike `Executor`, driver is stateless.
+
+        Therefore, on every save, it creates a new & empty driver object and save it.
+        """
+
+        d = dict(self.__class__(**self._init_kwargs_dict).__dict__)
         return d
 
 
@@ -237,6 +246,15 @@ class BaseRecursiveDriver(BaseDriver):
         super().__init__(*args, **kwargs)
         self._traversal_paths = [path.lower() for path in traversal_paths]
 
+    def _apply_root(
+        self,
+        docs: 'DocumentSet',
+        field: str,
+        *args,
+        **kwargs,
+    ) -> None:
+        return self._apply_all(docs, None, field, *args, **kwargs)
+
     # TODO(Han): probably want to publicize this, as it is not obvious for driver
     #  developer which one should be inherited
     def _apply_all(
@@ -254,20 +272,13 @@ class BaseRecursiveDriver(BaseDriver):
         :param field: where ``docs`` comes from, either ``matches`` or ``chunks``
         """
 
-    @property
-    def docs(self):
-        if self.expect_parts > 1:
-            return (d for r in reversed(self.partial_reqs) for d in r.docs)
-        else:
-            return self.req.docs
-
     def __call__(self, *args, **kwargs):
         self._traverse_apply(self.docs, *args, **kwargs)
 
     def _traverse_apply(self, docs: 'DocumentSet', *args, **kwargs) -> None:
         for path in self._traversal_paths:
             if path[0] == 'r':
-                self._traverse_rec(docs, None, None, [], *args, **kwargs)
+                self._apply_root(docs, 'docs', *args, **kwargs)
             for doc in docs:
                 self._traverse_rec(
                     [doc],
@@ -295,11 +306,11 @@ class BaseRecursiveDriver(BaseDriver):
 
 
 class BaseExecutableDriver(BaseRecursiveDriver):
-    """A :class:`BaseExecutableDriver` is an intermediate logic unit between the :class:`jina.peapods.pea.BasePea` and :class:`jina.executors.BaseExecutor`
+    """A :class:`BaseExecutableDriver` is an intermediate logic unit between the :class:`jina.peapods.runtimes.zmq.zed.ZEDRuntime` and :class:`jina.executors.BaseExecutor`
     It reads the protobuf message, extracts/modifies the required information and then sends to the :class:`jina.executors.BaseExecutor`,
-    finally it returns the message back to :class:`jina.peapods.pea.BasePea`.
+    finally it returns the message back to :class:`jina.peapods.runtimes.zmq.zed.ZEDRuntime`.
 
-    A :class:`BaseExecutableDriver` needs to be :attr:`attached` to a :class:`jina.peapods.pea.BasePea` and :class:`jina.executors.BaseExecutor` before using.
+    A :class:`BaseExecutableDriver` needs to be :attr:`attached` to a :class:`jina.peapods.runtimes.zmq.zed.ZEDRuntime` and :class:`jina.executors.BaseExecutor` before using.
     This is done by :func:`attach`. Note that a deserialized :class:`BaseDriver` from file is always unattached.
     """
 
@@ -325,7 +336,7 @@ class BaseExecutableDriver(BaseRecursiveDriver):
         """the function of :func:`jina.executors.BaseExecutor` to call """
         if (
             not self.msg.is_error
-            or self.pea.args.skip_on_error < SkipOnErrorType.EXECUTOR
+            or self.runtime.args.on_error_strategy < OnErrorStrategy.SKIP_EXECUTOR
         ):
             return self._exec_fn
         else:
