@@ -1,7 +1,7 @@
 from typing import Union, List, Iterator
 
 from .base import BaseFlow
-from ..clients.asyncio import AsyncClient
+from ..clients.asyncio import AsyncClient, AsyncWebSocketClient
 from ..clients.base import InputFnType, CallbackFnType
 from ..enums import DataInputType
 from ..helper import deprecated_alias
@@ -71,7 +71,11 @@ class AsyncFlow(BaseFlow):
     """
     _cls_client = AsyncClient  #: the type of the Client, can be changed to other class
 
-    @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
+    def _update_client(self):
+        if self._pod_nodes['gateway'].args.restful:
+            self._cls_client = AsyncWebSocketClient
+
+    @deprecated_alias(buffer=('input_fn', 1), callback=('on_done', 1), output_fn=('on_done', 1))
     async def train(self, input_fn: InputFnType = None,
                     on_done: CallbackFnType = None,
                     on_error: CallbackFnType = None,
@@ -115,7 +119,7 @@ class AsyncFlow(BaseFlow):
         """
         return await self._get_client(**kwargs).train(input_fn, on_done, on_error, on_always, **kwargs)
 
-    @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
+    @deprecated_alias(buffer=('input_fn', 1), callback=('on_done', 1), output_fn=('on_done', 1))
     async def index_ndarray(self, array: 'np.ndarray', axis: int = 0, size: int = None, shuffle: bool = False,
                             on_done: CallbackFnType = None,
                             on_error: CallbackFnType = None,
@@ -137,7 +141,7 @@ class AsyncFlow(BaseFlow):
                                                       on_done, on_error, on_always, data_type=DataInputType.CONTENT,
                                                       **kwargs)
 
-    @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
+    @deprecated_alias(buffer=('input_fn', 1), callback=('on_done', 1), output_fn=('on_done', 1))
     async def search_ndarray(self, array: 'np.ndarray', axis: int = 0, size: int = None, shuffle: bool = False,
                              on_done: CallbackFnType = None,
                              on_error: CallbackFnType = None,
@@ -155,10 +159,11 @@ class AsyncFlow(BaseFlow):
         :param kwargs: accepts all keyword arguments of `jina client` CLI
         """
         from ..clients.sugary_io import _input_ndarray
-        await self._get_client(**kwargs).search(_input_ndarray(array, axis, size, shuffle),
-                                                on_done, on_error, on_always, data_type=DataInputType.CONTENT, **kwargs)
+        return await self._get_client(**kwargs).search(_input_ndarray(array, axis, size, shuffle),
+                                                       on_done, on_error, on_always, data_type=DataInputType.CONTENT,
+                                                       **kwargs)
 
-    @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
+    @deprecated_alias(buffer=('input_fn', 1), callback=('on_done', 1), output_fn=('on_done', 1))
     async def index_lines(self, lines: Iterator[str] = None, filepath: str = None, size: int = None,
                           sampling_rate: float = None, read_mode='r',
                           on_done: CallbackFnType = None,
@@ -183,7 +188,7 @@ class AsyncFlow(BaseFlow):
                                                       on_done, on_error, on_always, data_type=DataInputType.CONTENT,
                                                       **kwargs)
 
-    @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
+    @deprecated_alias(buffer=('input_fn', 1), callback=('on_done', 1), output_fn=('on_done', 1))
     async def index_files(self, patterns: Union[str, List[str]], recursive: bool = True,
                           size: int = None, sampling_rate: float = None, read_mode: str = None,
                           on_done: CallbackFnType = None,
@@ -209,7 +214,7 @@ class AsyncFlow(BaseFlow):
                                                       on_done, on_error, on_always, data_type=DataInputType.CONTENT,
                                                       **kwargs)
 
-    @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
+    @deprecated_alias(buffer=('input_fn', 1), callback=('on_done', 1), output_fn=('on_done', 1))
     async def search_files(self, patterns: Union[str, List[str]], recursive: bool = True,
                            size: int = None, sampling_rate: float = None, read_mode: str = None,
                            on_done: CallbackFnType = None,
@@ -235,7 +240,7 @@ class AsyncFlow(BaseFlow):
             _input_files(patterns, recursive, size, sampling_rate, read_mode),
             on_done, on_error, on_always, data_type=DataInputType.CONTENT, **kwargs)
 
-    @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
+    @deprecated_alias(buffer=('input_fn', 1), callback=('on_done', 1), output_fn=('on_done', 1))
     async def search_lines(self, filepath: str = None, lines: Iterator[str] = None, size: int = None,
                            sampling_rate: float = None, read_mode='r',
                            on_done: CallbackFnType = None,
@@ -260,7 +265,7 @@ class AsyncFlow(BaseFlow):
                                                        on_done, on_error, on_always, data_type=DataInputType.CONTENT,
                                                        **kwargs)
 
-    @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
+    @deprecated_alias(buffer=('input_fn', 1), callback=('on_done', 1), output_fn=('on_done', 1))
     async def index(self, input_fn: InputFnType = None,
                     on_done: CallbackFnType = None,
                     on_error: CallbackFnType = None,
@@ -304,7 +309,7 @@ class AsyncFlow(BaseFlow):
         """
         return await self._get_client(**kwargs).index(input_fn, on_done, on_error, on_always, **kwargs)
 
-    @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
+    @deprecated_alias(buffer=('input_fn', 1), callback=('on_done', 1), output_fn=('on_done', 1))
     async def search(self, input_fn: InputFnType = None,
                      on_done: CallbackFnType = None,
                      on_error: CallbackFnType = None,
