@@ -15,7 +15,7 @@ class ImageCropper(BaseCrafter):
         the :py:mode:`PIL.Image`.
     """
 
-    def __init__(self, top: int, left: int, height: int, width: int, channel_axis: int = -1, *args, **kwargs):
+    def __init__(self, top: int = 0, left: int = 0, height: int = 224, width: int = 224, channel_axis: int = -1, *args, **kwargs):
         """
 
         :param top: the vertical coordinate of the top left corner of the crop box.
