@@ -23,6 +23,7 @@ class BasePod(ExitStack):
         """
         super().__init__()
         self.args = args
+        BasePod._set_conditional_args(self.args)
         self.needs = needs if needs else set()  #: used in the :class:`jina.flow.Flow` to build the graph
 
         self.peas = []  # type: List['BasePea']
@@ -38,7 +39,7 @@ class BasePod(ExitStack):
             self.peas_args = self._parse_args(args)
 
         for a in self.all_args:
-            self._set_conditional_args(a)
+            BasePod._set_conditional_args(a)
 
     @property
     def role(self) -> 'PodRoleType':
@@ -105,7 +106,8 @@ class BasePod(ExitStack):
             peas_args['head'] = _copy_to_head_args(args, args.polling.is_push)
             peas_args['tail'] = _copy_to_tail_args(args)
             peas_args['peas'] = _set_peas_args(args, peas_args['head'], peas_args['tail'])
-        elif getattr(args, 'uses_before', None) or getattr(args, 'uses_after', None):
+        elif (getattr(args, 'uses_before', None) and args.uses_before != '_pass') or (
+                getattr(args, 'uses_after', None) and args.uses_after != '_pass'):
             args.scheduling = SchedulerType.ROUND_ROBIN
             if getattr(args, 'uses_before', None):
                 self.is_head_router = True
@@ -223,13 +225,11 @@ class BasePod(ExitStack):
 
     @staticmethod
     def _set_conditional_args(args):
-        if args.pod_role == PodRoleType.GATEWAY:
+        if 'pod_role' in args and args.pod_role == PodRoleType.GATEWAY:
             if args.restful:
                 args.runtime_cls = 'RESTRuntime'
             else:
                 args.runtime_cls = 'GRPCRuntime'
-        if 'parallel' in args and args.parallel == 1:
-            args.separated_workspace = False
 
     def connect_to_tail_of(self, pod: 'BasePod'):
         """Eliminate the head node by connecting prev_args node directly to peas """
@@ -267,4 +267,4 @@ class BasePod(ExitStack):
     @property
     def is_ready(self) -> bool:
         """A Pod is ready when all the Peas it contains are ready"""
-        return all(p.is_ready.is_set() for p in self.peas)
\ No newline at end of file
+        return all(p.is_ready.is_set() for p in self.peas)
